/* player.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef PLAYER_H
#define PLAYER_H

#include <string>
#include <sys/types.h>

class CommandInterface;
class PlayerDef;
class Server;

class Player {
public:
  Player(int user_socket, Server *server);
  ~Player();

  void read_user_command();
  void interrupt();

  void set_filename(const string &filename, int type = -1, 
		    double length = 0.0);
  void set_cd_track(const string &cdrom_device, int track_num, 
		    double length = 0.0);
  void play(double start, double end);
  void stop();

  bool get_verbose() const;
  bool is_playing() const;
  double get_current_time() const;
  int get_total_frames() const;
  double get_total_time() const;

  int get_fd() const;
  void read_status();
  void feedback_user(string feedback);

private:
  void init_interface();
  void line_up_user_input(const string &input);
  void read_user_line(const string &line);

  bool _verbose;
  string _filename;
  int _track_num;
  CommandInterface *_interface;
  int _total_frames;
  double _total_time;

  const PlayerDef *_def;
  double _start_time, _end_time;
  double _last_reported_time;

  int _attempt_count;
  bool _is_valid;
  int _user_socket;
  string _user_input;
  Server *_server;
};

#endif
