/* dataset.C

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#include "system.h"

#include "dataset.h"


Dataset::
Dataset() {
  for (int i = 0; i < num_table_ids; i++) {
    _tables[i] = TableDataProxy((TableID)i);
  }
}

Dataset::
Dataset(const Dataset &copy) {
  (*this) = copy;
}

Dataset &Dataset::
operator = (const Dataset &copy) {
  for (int i = 0; i < num_table_ids; i++) {
    _tables[i] = copy._tables[i];
  }
  return *this;
}

TableDataProxy &Dataset::
operator [] (TableID table_id) {
  assert(table_id >= 0 && table_id < num_table_ids);
  assert(!_tables[table_id].has_table() || 
	 _tables[table_id].get_table_id() == table_id);
  return _tables[table_id];
}

const TableDataProxy &Dataset::
operator [] (TableID table_id) const {
  assert(table_id >= 0 && table_id < num_table_ids);
  assert(!_tables[table_id].has_table() || 
	 _tables[table_id].get_table_id() == table_id);
  return _tables[table_id];
}

